/* capture.c (c) 2004 Petr Danecek
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __CAPTURE_H__
#define __CAPTURE_H__

#define MAX_CMD_LEN 255	
#define USLEEP 50000
#define NMAX_CAMS 16

#include <string.h>
#include <stdio.h>
#include <sys/stat.h>
#include <assert.h>
#include <errno.h>
#include <stdarg.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/time.h>
#include <fcntl.h>
#include <usb.h>
#include <libptp2/ptp.h>
#include <stdio.h>
#include "props.h"

typedef struct
{
      usb_dev_handle* handle;
      int inep;
      int outep;
      int intep;
}
PTP_USB;

struct _cmd_t
{
      char *command;
      int ptpcode;
      int (*handler)(int, const struct _cmd_t*, const char*);
      allowed_t *params;
      char *help;
};

typedef struct _cmd_t cmd_t;

/*
 * the 'settings' struct
 */
typedef struct
{
    struct usb_device *dev;
    PTPParams params;
    PTP_USB ptp_usb;
    char bStarted;
    struct timeval timeLastPic;
}
settings_t;

void print(const char *format, ...);
void debug(const char *format, ...);
void info(const char *format, ...);

void scan_for_cameras();
int run_cameras();
int run_cam_cmd(int iCam, const char *cmd, const char *arg);
    
extern int DEBUG;
extern cmd_t cmds[];
extern settings_t settings[NMAX_CAMS];
extern int pbus[NMAX_CAMS], pdev[NMAX_CAMS];
extern int nCams;
extern int usPerPic;

int quit();
int start_camera(int);
int prop8_handler(int, const cmd_t *, const char *);
int prop16_handler(int, const cmd_t *, const char *);
int capture_file(int, const char *, ...);
int focuslock(int, int);
int value_ok(const allowed_t *all, const char *value);

#define BUFFSIZE 255
#define SEND_BUF_SIZE 1024

#define CMD_START "start"
#define CMD_SETTINGS "settings" /* get qual, res, zoom settings */
#define CMD_QUIT "quit"
#define CMD_STATUS "status"
#define CMD_UNKNOWN "Unknown command"
#define CMD_DEBUG "debug"
#define CMD_HELP "help"
#define CMD_ZOOM "zoom"
#define CMD_FLASH "flash"
#define CMD_CAPTURE "capture"
#define CMD_MACRO "macro"
#define CMD_APERTURE "aperture"
#define CMD_SHUTTER "shutter"
#define CMD_VF "viewfinder"
#define CMD_GETVF "getvf"
#define CMD_TVAV "tv/av"
#define CMD_FP "focuspoint"
#define CMD_FOCUS_LOCK "focus"
#define CMD_EXPCOMP "ecomp"
#define CMD_ISO_SPEED "iso"
#define CMD_WHITE_BAL "white"
#define CMD_PHOTO_EFFECT "effect"
#define CMD_LIGHT_METER "metering"
#define CMD_TEST "test"
#define CMD_QUAL "qual"
#define CMD_SIZE "size"
#define CMD_D045 "d045"   /*XXX ??! */

#endif

